Django FileBrowser
==================
.. image:: https://api.travis-ci.org/sehmaschine/django-filebrowser.svg
    :target: https://travis-ci.org/sehmaschine/django-filebrowser

.. image:: https://readthedocs.org/projects/django-filebrowser/badge/?version=latest
    :target: http://django-filebrowser.readthedocs.org/en/latest/?badge=latest

**Media-Management with Grappelli**.

The FileBrowser is an extension to the `Django <http://www.djangoproject.com>`_ administration interface in order to:

* browse directories on your server and upload/delete/edit/rename files.
* include images/documents to your models/database using the ``FileBrowseField``.
* select images/documents with TinyMCE.

Requirements
------------

FileBrowser 3.13.1 requires

* Django 3.0 (http://www.djangoproject.com)
* Grappelli 2.14 (https://github.com/sehmaschine/django-grappelli)
* Pillow (https://github.com/python-imaging/Pillow)

Documentation
-------------

http://readthedocs.org/docs/django-filebrowser/

Translation
-----------

https://www.transifex.com/projects/p/django-filebrowser/

Releases
--------

* FileBrowser 3.13.1 (May 15th, 2020): Compatible with Django 3.0
* FileBrowser 3.12.1 (November 14th, 2019): Compatible with Django 2.2 (LTS)
* FileBrowser 3.9.2 (November 2nd, 2018): Compatible with Django 1.11 (LTS)

Current development branches:

* FileBrowser 3.13.1 (Development Version for Django = 3.0, see Branch Stable/3.13.x)
* FileBrowser 3.12.2 (Development Version for Django = 2.2, see Branch Stable/3.12.x)
* FileBrowser 3.9.3 (Development Version for Django = 1.11, see Branch Stable/3.9.x)

Older versions are available at GitHub, but are not supported anymore.
Support for 3.12.x and 3.9.x is limited to security issues and very important bugfixes.
